MemoryTracker class

Tracks application memory usage.

Uses a platform channel (flutter_app_vitals/memory) when native code is registered. Falls back to ProcessInfo.currentRss from dart:io.

Native handler should respond to getMemoryUsage with a double (MB).

Constructors

MemoryTracker()

Properties

currentMemoryMb double
Last recorded memory usage in megabytes.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update() Future<void>
Query current memory usage and cache the result.

Operators

operator ==(Object other) bool
The equality operator.
inherited