NetworkRequestRecord class

A single tracked network request.

Properties

endTime DateTime?
When the request completed (null if still in-flight).
no setter
hashCode int
The hash code for this object.
no setterinherited
isFailed bool
Whether the request failed (status >= 400 or status 0 for errors).
no setter
latency Duration?
Round-trip latency (null if still in-flight).
no setter
method String
HTTP method (GET, POST, etc.).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
When the request was initiated.
final
statusCode int?
HTTP status code (null if still in-flight).
no setter
url String
Request URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited