StartupTracker class

Tracks the time from app start until the first frame is rendered.

Constructors

StartupTracker()

Properties

hasCompleted bool
Whether stop has been called.
no setter
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Whether the timer is currently running.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startupTimeMs double
Elapsed startup time in milliseconds.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Begin timing. Call this as early as possible (e.g. in main()).
stop() → void
Stop timing. Call this after the first frame renders.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited